==> kubernetes-model-flowcontrol-6.5.1-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/LimitedPriorityLevelConfigurationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LimitedPriorityLevelConfigurationFluentImpl<A extends LimitedPriorityLevelConfigurationFluent<A>> extends BaseFluent<A> implements LimitedPriorityLevelConfigurationFluent<A>{
  public LimitedPriorityLevelConfigurationFluentImpl() {
  }
  public LimitedPriorityLevelConfigurationFluentImpl(LimitedPriorityLevelConfiguration instance) {
    this.withBorrowingLimitPercent(instance.getBorrowingLimitPercent()); 
    this.withLendablePercent(instance.getLendablePercent()); 
    this.withLimitResponse(instance.getLimitResponse()); 
    this.withNominalConcurrencyShares(instance.getNominalConcurrencyShares()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private Integer borrowingLimitPercent;
  private Integer lendablePercent;
  private LimitResponseBuilder limitResponse;
  private Integer nominalConcurrencyShares;
  private Map<String,Object> additionalProperties;
  public Integer getBorrowingLimitPercent() {
    return this.borrowingLimitPercent;
  }
  public A withBorrowingLimitPercent(Integer borrowingLimitPercent) {
    this.borrowingLimitPercent=borrowingLimitPercent; return (A) this;
  }
  public Boolean hasBorrowingLimitPercent() {
    return this.borrowingLimitPercent != null;
  }
  public Integer getLendablePercent() {
    return this.lendablePercent;
  }
  public A withLendablePercent(Integer lendablePercent) {
    this.lendablePercent=lendablePercent; return (A) this;
  }
  public Boolean hasLendablePercent() {
    return this.lendablePercent != null;
  }
  
  /**
   * This method has been deprecated, please use method buildLimitResponse instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitResponse getLimitResponse() {
    return this.limitResponse!=null ?this.limitResponse.build():null;
  }
  public LimitResponse buildLimitResponse() {
    return this.limitResponse!=null ?this.limitResponse.build():null;
  }
  public A withLimitResponse(LimitResponse limitResponse) {
    _visitables.get("limitResponse").remove(this.limitResponse);
    if (limitResponse!=null){ this.limitResponse= new LimitResponseBuilder(limitResponse); _visitables.get("limitResponse").add(this.limitResponse);} else { this.limitResponse = null; _visitables.get("limitResponse").remove(this.limitResponse); } return (A) this;
  }
  public Boolean hasLimitResponse() {
    return this.limitResponse != null;
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponse() {
    return new LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNestedImpl();
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> withNewLimitResponseLike(LimitResponse item) {
    return new LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNestedImpl(item);
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editLimitResponse() {
    return withNewLimitResponseLike(getLimitResponse());
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponse() {
    return withNewLimitResponseLike(getLimitResponse() != null ? getLimitResponse(): new LimitResponseBuilder().build());
  }
  public LimitedPriorityLevelConfigurationFluent.LimitResponseNested<A> editOrNewLimitResponseLike(LimitResponse item) {
    return withNewLimitResponseLike(getLimitResponse() != null ? getLimitResponse(): item);
  }
  public Integer getNominalConcurrencyShares() {
    return this.nominalConcurrencyShares;
  }
  public A withNominalConcurrencyShares(Integer nominalConcurrencyShares) {
    this.nominalConcurrencyShares=nominalConcurrencyShares; return (A) this;
  }
  public Boolean hasNominalConcurrencyShares() {
    return this.nominalConcurrencyShares != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    LimitedPriorityLevelConfigurationFluentImpl that = (LimitedPriorityLevelConfigurationFluentImpl) o;
    if (borrowingLimitPercent != null ? !borrowingLimitPercent.equals(that.borrowingLimitPercent) :that.borrowingLimitPercent != null) return false;
    if (lendablePercent != null ? !lendablePercent.equals(that.lendablePercent) :that.lendablePercent != null) return false;
    if (limitResponse != null ? !limitResponse.equals(that.limitResponse) :that.limitResponse != null) return false;
    if (nominalConcurrencyShares != null ? !nominalConcurrencyShares.equals(that.nominalConcurrencyShares) :that.nominalConcurrencyShares != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(borrowingLimitPercent,  lendablePercent,  limitResponse,  nominalConcurrencyShares,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (borrowingLimitPercent != null) { sb.append("borrowingLimitPercent:"); sb.append(borrowingLimitPercent + ","); }
    if (lendablePercent != null) { sb.append("lendablePercent:"); sb.append(lendablePercent + ","); }
    if (limitResponse != null) { sb.append("limitResponse:"); sb.append(limitResponse + ","); }
    if (nominalConcurrencyShares != null) { sb.append("nominalConcurrencyShares:"); sb.append(nominalConcurrencyShares + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class LimitResponseNestedImpl<N> extends LimitResponseFluentImpl<LimitedPriorityLevelConfigurationFluent.LimitResponseNested<N>> implements LimitedPriorityLevelConfigurationFluent.LimitResponseNested<N>,Nested<N>{
    LimitResponseNestedImpl(LimitResponse item) {
      this.builder = new LimitResponseBuilder(this, item);
    }
    LimitResponseNestedImpl() {
      this.builder = new LimitResponseBuilder(this);
    }
    LimitResponseBuilder builder;
    public N and() {
      return (N) LimitedPriorityLevelConfigurationFluentImpl.this.withLimitResponse(builder.build());
    }
    public N endLimitResponse() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-flowcontrol-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/flowcontrol/v1beta3/LimitedPriorityLevelConfigurationFluentImpl.java <==
package io.fabric8.kubernetes.api.model.flowcontrol.v1beta3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LimitedPriorityLevelConfigurationFluentImpl<A extends LimitedPriorityLevelConfigurationFluent<A>> extends BaseFluent<A> implements LimitedPriorityLevelConfigurationFluent<A>{
  public LimitedPriorityLevelConfigurationFluentImpl() {
  }
  public LimitedPriorityLevelConfigurationFluentImpl(LimitedPriorityLevelConfiguration instance) {
    if (instance != null) {
      this.withBorrowingLimitPercent(instance.getBorrowingLimitPercent());
      this.withLendablePercent(instance.getLendablePercent());
      this.withLimitResponse(instance.getLimitResponse());
      this.withNominalConcurrencyShares(instance.getNominalConcurrencyShares());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private Integer borrowingLimitPercent;
  private Integer lendablePercent;
  private LimitResponseBuilder limitResponse;
  private Integer nominalConcurrencyShares;
  private Map<String,Object> additionalProperties;
  public Integer getBorrowingLimitPercent() {
    return this.borrowingLimitPercent;
  }
  public A withBorrowingLimitPercent(Integer borrowingLimitPercent) {
    this.borrowingLimitPercent=borrowingLimitPercent; return (A) this;
  }
  public Boolean hasBorrowingLimitPercent() {
    return this.borrowingLimitPercent != null;
  }
  public Integer getLendablePercent() {
    return this.lendablePercent;
  }
  public A withLendablePercent(Integer lendablePercent) {
    this.lendablePercent=lendablePercent; return (A) this;
  }
  public Boolean hasLendablePercent() {
    return this.lendablePercent != null;
  }
  
  /**
   * This method has been deprecated, please use method buildLimitResponse instead.
   * @return The buildable object.
   */
  @Deprecated
  public LimitResponse getLimitResponse() {
    return this.limitResponse!=null ?this.limitResponse.build():null;
  }
  public LimitResponse buildLimitResponse() {
    return this.limitResponse!=null ?this.limitResponse.build():null;
  }
  public A withLimitResponse(LimitResponse limitResponse) {
    _visitables.get("limitResponse").remove(this.limitResponse);
    if (limitResponse!=null){ this.limitResponse= new LimitResponseBuilder(limitResponse); _visitables.get("limitResponse").add(this.limitResponse);} else { this.limitResponse = null; _visitables.get("limitResponse").remove(this.limitResponse); } return (A) this;
  }
  public Boolean hasLimitResponse() {
    return this.limitResponse != null;
  }
  public LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNested<A> withNewLimitResponse() {
    return new LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNestedImpl();
  }
  public LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNested<A> withNewLimitResponseLike(LimitResponse item) {
    return new LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNestedImpl(item);
  }
  public LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNested<A> editLimitResponse() {
    return withNewLimitResponseLike(getLimitResponse());
  }
  public LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNested<A> editOrNewLimitResponse() {
    return withNewLimitResponseLike(getLimitResponse() != null ? getLimitResponse(): new LimitResponseBuilder().build());
  }
  public LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNested<A> editOrNewLimitResponseLike(LimitResponse item) {
    return withNewLimitResponseLike(getLimitResponse() != null ? getLimitResponse(): item);
  }
  public Integer getNominalConcurrencyShares() {
    return this.nominalConcurrencyShares;
  }
  public A withNominalConcurrencyShares(Integer nominalConcurrencyShares) {
    this.nominalConcurrencyShares=nominalConcurrencyShares; return (A) this;
  }
  public Boolean hasNominalConcurrencyShares() {
    return this.nominalConcurrencyShares != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LimitedPriorityLevelConfigurationFluentImpl that = (LimitedPriorityLevelConfigurationFluentImpl) o;
    if (!java.util.Objects.equals(borrowingLimitPercent, that.borrowingLimitPercent)) return false;

    if (!java.util.Objects.equals(lendablePercent, that.lendablePercent)) return false;

    if (!java.util.Objects.equals(limitResponse, that.limitResponse)) return false;

    if (!java.util.Objects.equals(nominalConcurrencyShares, that.nominalConcurrencyShares)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(borrowingLimitPercent,  lendablePercent,  limitResponse,  nominalConcurrencyShares,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (borrowingLimitPercent != null) { sb.append("borrowingLimitPercent:"); sb.append(borrowingLimitPercent + ","); }
    if (lendablePercent != null) { sb.append("lendablePercent:"); sb.append(lendablePercent + ","); }
    if (limitResponse != null) { sb.append("limitResponse:"); sb.append(limitResponse + ","); }
    if (nominalConcurrencyShares != null) { sb.append("nominalConcurrencyShares:"); sb.append(nominalConcurrencyShares + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class LimitResponseNestedImpl<N> extends LimitResponseFluentImpl<LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNested<N>> implements LimitedPriorityLevelConfigurationFluentImpl.LimitResponseNested<N>,Nested<N>{
    LimitResponseNestedImpl(LimitResponse item) {
      this.builder = new LimitResponseBuilder(this, item);
    }
    LimitResponseNestedImpl() {
      this.builder = new LimitResponseBuilder(this);
    }
    LimitResponseBuilder builder;
    public N and() {
      return (N) LimitedPriorityLevelConfigurationFluentImpl.this.withLimitResponse(builder.build());
    }
    public N endLimitResponse() {
      return and();
    }
    
  }
  
}
